==> com.liferay.dynamic.data.mapping.form.renderer-4.0.65.jar: META-INF/resources/js/components/PageRenderer/PageRenderer.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.65/js/components/PageRenderer/PageRenderer.es", ['module', 'exports', 'require', './PaginatedPageRenderer.soy', './SimplePageRenderer.soy', './TabbedPageRenderer.soy', './WizardPageRenderer.soy', 'frontend-taglib-clay$clay-button', 'frontend-taglib-clay$clay-dropdown', 'frontend-taglib-clay$clay-modal', 'frontend-taglib-clay$clay-icon', 'frontend-js-metal-web$metal', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', '../FormRenderer/FormSupport.es', './PageRenderer.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  require("./PaginatedPageRenderer.soy");

  require("./SimplePageRenderer.soy");

  require("./TabbedPageRenderer.soy");

  require("./WizardPageRenderer.soy");

  require("frontend-taglib-clay$clay-button");

  require("frontend-taglib-clay$clay-dropdown");

  require("frontend-taglib-clay$clay-modal");

  require("frontend-taglib-clay$clay-icon");

  var _metal = _interopRequireDefault(require("frontend-js-metal-web$metal"));

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var FormSupport = _interopRequireWildcard(require("../FormRenderer/FormSupport.es"));

  var _PageRenderer = _interopRequireDefault(require("./PageRenderer.soy"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ADMIN_PORTLET_NAMESPACE = '_com_liferay_dynamic_data_mapping_form_web_portlet_DDMFormAdminPortlet_';

  var PageRenderer = /*#__PURE__*/function (_Component) {
    _inherits(PageRenderer, _Component);

    function PageRenderer() {
      _classCallCheck(this, PageRenderer);

      return _possibleConstructorReturn(this, _getPrototypeOf(PageRenderer).apply(this, arguments));
    }

    _createClass(PageRenderer, [{
      key: "getPage",
      value: function getPage(page) {
        var editingLanguageId = this.editingLanguageId;

        if (_metal["default"].isObject(page.description)) {
          page = _objectSpread({}, page, {
            description: page.description[editingLanguageId]
          });
        }

        if (_metal["default"].isObject(page.title)) {
          page = _objectSpread({}, page, {
            title: page.title[editingLanguageId]
          });
        }

        return page;
      }
    }, {
      key: "isEmptyPage",
      value: function isEmptyPage(_ref) {
        var rows = _ref.rows;
        var empty = false;

        if (!rows || !rows.length) {
          empty = true;
        } else {
          empty = !rows.some(function (_ref2) {
            var columns = _ref2.columns;
            var hasFields = true;

            if (!columns) {
              hasFields = false;
            } else {
              hasFields = columns.some(function (column) {
                return column.fields.length;
              });
            }

            return hasFields;
          });
        }

        return empty;
      }
    }, {
      key: "hasFieldRequired",
      value: function hasFieldRequired(_ref3) {
        var rows = _ref3.rows;
        var hasFieldRequired = false;

        if (rows && rows.length) {
          hasFieldRequired = rows.some(function (_ref4) {
            var columns = _ref4.columns;

            if (columns && columns.length) {
              return columns.some(function (column) {
                if (column && column.fields.length) {
                  return column.fields.some(function (field) {
                    return field.required;
                  });
                }

                return false;
              });
            }

            return false;
          });
        }

        return hasFieldRequired;
      }
    }, {
      key: "prepareStateForRender",
      value: function prepareStateForRender(states) {
        return _objectSpread({}, states, {
          empty: this.isEmptyPage(states.page),
          hasFieldRequired: this.hasFieldRequired(states.page),
          indicatesRequiredFields: Liferay.Language.get('indicates-required-fields'),
          isAdminPortletNamespace: ADMIN_PORTLET_NAMESPACE === states.portletNamespace,
          page: this.getPage(states.page)
        });
      }
    }, {
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        this.emit('fieldBlurred', event);
      }
    }, {
      key: "_handleFieldClicked",
      value: function _handleFieldClicked(_ref5) {
        var delegateTarget = _ref5.delegateTarget;
        var fieldNode = delegateTarget.parentElement.parentElement;
        var indexes = FormSupport.getIndexes(fieldNode);
        this.emit('fieldClicked', _objectSpread({}, indexes));
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        this.emit('fieldEdited', event);
      }
    }, {
      key: "_handleFieldFocused",
      value: function _handleFieldFocused(event) {
        this.emit('fieldFocused', event);
      }
    }]);

    return PageRenderer;
  }(_metalComponent["default"]);

  PageRenderer.STATE = {
    /**
     * @instance
     * @memberof FormPage
     * @type {?number}
     */
    activePage: _metalState.Config.number().value(0),

    /**
     * @instance
     * @memberof FormPage
     * @type {?boolean}
     */
    editable: _metalState.Config.bool().value(false),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    page: _metalState.Config.object(),

    /**
     * @default 1
     * @instance
     * @memberof FormPage
     * @type {?number}
     */
    pageIndex: _metalState.Config.number().value(0),

    /**
     * @default undefined
     * @instance
     * @memberof FormRenderer
     * @type {!string}
     */
    spritemap: _metalState.Config.string().required()
  };

  _metalSoy["default"].register(PageRenderer, _PageRenderer["default"]);

  var _default = PageRenderer;
  exports["default"] = _default;
  //# sourceMappingURL=PageRenderer.es.js.map
});
//# sourceMappingURL=PageRenderer.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-4.0.69.jar: META-INF/resources/js/components/PageRenderer/PageRenderer.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.69/js/components/PageRenderer/PageRenderer.es", ['module', 'exports', 'require', './PaginatedPageRenderer.soy', './SimplePageRenderer.soy', './TabbedPageRenderer.soy', './WizardPageRenderer.soy', 'frontend-taglib-clay$clay-button', 'frontend-taglib-clay$clay-dropdown', 'frontend-taglib-clay$clay-modal', 'frontend-taglib-clay$clay-icon', 'frontend-js-metal-web$metal', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-dom', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', '../FormRenderer/FormSupport.es', './PageRenderer.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  require("./PaginatedPageRenderer.soy");

  require("./SimplePageRenderer.soy");

  require("./TabbedPageRenderer.soy");

  require("./WizardPageRenderer.soy");

  require("frontend-taglib-clay$clay-button");

  require("frontend-taglib-clay$clay-dropdown");

  require("frontend-taglib-clay$clay-modal");

  require("frontend-taglib-clay$clay-icon");

  var _metal = _interopRequireDefault(require("frontend-js-metal-web$metal"));

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalDom = _interopRequireDefault(require("frontend-js-metal-web$metal-dom"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var FormSupport = _interopRequireWildcard(require("../FormRenderer/FormSupport.es"));

  var _PageRenderer = _interopRequireDefault(require("./PageRenderer.soy"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ADMIN_PORTLET_NAMESPACE = '_com_liferay_dynamic_data_mapping_form_web_portlet_DDMFormAdminPortlet_';

  var PageRenderer = /*#__PURE__*/function (_Component) {
    _inherits(PageRenderer, _Component);

    function PageRenderer() {
      _classCallCheck(this, PageRenderer);

      return _possibleConstructorReturn(this, _getPrototypeOf(PageRenderer).apply(this, arguments));
    }

    _createClass(PageRenderer, [{
      key: "getPage",
      value: function getPage(page) {
        var editingLanguageId = this.editingLanguageId;

        if (_metal["default"].isObject(page.description)) {
          page = _objectSpread({}, page, {
            description: page.description[editingLanguageId]
          });
        }

        if (_metal["default"].isObject(page.title)) {
          page = _objectSpread({}, page, {
            title: page.title[editingLanguageId]
          });
        }

        return page;
      }
    }, {
      key: "isEmptyPage",
      value: function isEmptyPage(_ref) {
        var rows = _ref.rows;
        var empty = false;

        if (!rows || !rows.length) {
          empty = true;
        } else {
          empty = !rows.some(function (_ref2) {
            var columns = _ref2.columns;
            var hasFields = true;

            if (!columns) {
              hasFields = false;
            } else {
              hasFields = columns.some(function (column) {
                return column.fields.length;
              });
            }

            return hasFields;
          });
        }

        return empty;
      }
    }, {
      key: "hasFieldRequired",
      value: function hasFieldRequired(_ref3) {
        var rows = _ref3.rows;
        var hasFieldRequired = false;

        if (rows && rows.length) {
          hasFieldRequired = rows.some(function (_ref4) {
            var columns = _ref4.columns;

            if (columns && columns.length) {
              return columns.some(function (column) {
                if (column && column.fields.length) {
                  return column.fields.some(function (field) {
                    return field.required;
                  });
                }

                return false;
              });
            }

            return false;
          });
        }

        return hasFieldRequired;
      }
    }, {
      key: "prepareStateForRender",
      value: function prepareStateForRender(states) {
        return _objectSpread({}, states, {
          empty: this.isEmptyPage(states.page),
          hasFieldRequired: this.hasFieldRequired(states.page),
          indicatesRequiredFields: Liferay.Language.get('indicates-required-fields'),
          isAdminPortletNamespace: ADMIN_PORTLET_NAMESPACE === states.portletNamespace,
          page: this.getPage(states.page)
        });
      }
    }, {
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        this.emit('fieldBlurred', event);
      }
    }, {
      key: "_handleFieldClicked",
      value: function _handleFieldClicked(event) {
        var delegateTarget = event.delegateTarget;
        var fieldName = delegateTarget.dataset.fieldName;
        event.stopPropagation();
        this.emit('fieldClicked', _objectSpread({}, FormSupport.getIndexes(_metalDom["default"].closest(delegateTarget, '.col-ddm')), {
          fieldName: fieldName,
          originalEvent: event
        }));
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        this.emit('fieldEdited', event);
      }
    }, {
      key: "_handleFieldFocused",
      value: function _handleFieldFocused(event) {
        this.emit('fieldFocused', event);
      }
    }]);

    return PageRenderer;
  }(_metalComponent["default"]);

  PageRenderer.STATE = {
    /**
     * @instance
     * @memberof FormPage
     * @type {?number}
     */
    activePage: _metalState.Config.number().value(0),

    /**
     * @instance
     * @memberof FormPage
     * @type {?boolean}
     */
    editable: _metalState.Config.bool().value(false),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    page: _metalState.Config.object(),

    /**
     * @default 1
     * @instance
     * @memberof FormPage
     * @type {?number}
     */
    pageIndex: _metalState.Config.number().value(0),

    /**
     * @default undefined
     * @instance
     * @memberof FormRenderer
     * @type {!string}
     */
    spritemap: _metalState.Config.string().required()
  };

  _metalSoy["default"].register(PageRenderer, _PageRenderer["default"]);

  var _default = PageRenderer;
  exports["default"] = _default;
  //# sourceMappingURL=PageRenderer.es.js.map
});
//# sourceMappingURL=PageRenderer.es.js.map
